@@ -7,9 +7,9 @@ OC.L10N.register(
     "Open »%s«" : "Malfermi „%s“",
     "Cheers!" : "Ĝis!",
     "Upcoming events" : "Venontaj eventoj",
-    "More events" : "Pliaj eventoj",
     "No more events today" : "Ne plu eventoj hodiaŭ",
     "No upcoming events" : "Neniuj venontaj eventoj",
+    "More events" : "Pliaj eventoj",
     "Calendar" : "Kalendaro",
     "New booking {booking}" : "Nova rezervo {booking}",
     "Confirm" : "Konfirmi",
@@ -26,15 +26,16 @@ OC.L10N.register(
     "Copy link" : "Kopii ligilon",
     "Edit" : "Modifi",
     "Delete" : "Forigi",
+    "Create new" : "Krei nove",
     "New calendar" : "Nova kalendaro",
-    "Export" : "Eksporti",
     "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
     "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
+    "Export" : "Eksporti",
+    "Empty trash bin" : "Malpleni rubujon",
     "Name" : "Nomo",
     "Deleted" : "Forigita",
     "Restore" : "Restaŭri",
     "Delete permanently" : "Forigi por ĉiam",
-    "Empty trash bin" : "Malpleni rubujon",
     "Deck" : "Kartaro",
     "Hidden" : "Nevidebla",
     "Internal link" : "Interna ligilo",
@@ -47,18 +48,19 @@ OC.L10N.register(
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
-    "or" : "aŭ",
     "Previous period" : "Antaŭa periodo",
     "List view" : "Lista vido",
     "Actions" : "Agoj",
     "Editor" : "Redaktilo",
     "Close editor" : "Fermi redaktilon",
+    "or" : "aŭ",
     "Enable birthday calendar" : "Ebligi naskiĝtaga kalendaro",
     "Show tasks in calendar" : "Montri taskojn en la kalendaro",
     "Enable simplified editor" : "Ebligi simpligitan redaktilon",
     "Show weekends" : "Montri semajnfinojn",
     "Show week numbers" : "Montri numerojn de semajno",
     "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn",
+    "Update" : "Ĝisdatigi",
     "Location" : "Loko",
     "Description" : "Priskribo",
     "to" : "al",
@@ -72,62 +74,63 @@ OC.L10N.register(
     "Sunday" : "Dimanĉo",
     "Before the event" : "Antaŭe la evento",
     "After the event" : "Post la evento",
-    "Update" : "Ĝisdatigi",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ni sendis al vi retmesaĝon kun detaloj. Bonvolu konfirmi vian rendevuon per la ligilo en la retpoŝto. Vi povas fermi ĉi tiun paĝon nun.",
     "Your email address" : "Via retpoŝta adreso",
     "Notification" : "Atentigo",
     "Email" : "Retpoŝto",
-    "_second_::_seconds_" : ["sekundo","sekundoj"],
-    "_minute_::_minutes_" : ["minuto","minutoj"],
-    "_hour_::_hours_" : ["horo","horoj"],
-    "_day_::_days_" : ["tago","tagoj"],
-    "_week_::_weeks_" : ["semajno","semajnoj"],
-    "Delete file" : "Forigi dosieron",
+    "seconds" : "sekundoj",
+    "minutes" : "minutoj",
+    "hours" : "horojn",
+    "days" : "tagojn",
+    "weeks" : "semajnoj",
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
+    "Delete file" : "Forigi dosieron",
     "Available" : "Disponeble",
     "Not available" : "Ne disponeble",
+    "Out of office" : "Ekstere oficejo",
     "Done" : "Farita",
     "Busy" : "Okupita",
-    "Out of office" : "Ekstere oficejo",
     "Unknown" : "Nekonata",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
     "Tentative" : "Nekonfirmita",
     "Attendees" : "Ĉeestontoj",
+    "Remove group" : "Forigi grupon",
     "Required participant" : "Bezonata partoprenanto",
     "Optional participant" : "Laŭvola partoprenanto",
-    "Remove group" : "Forigi grupon",
-    "All day" : "Tuttage",
+    "From" : "De",
+    "To" : "Al",
     "Repeat" : "Ripeti",
     "never" : "neniam",
     "after" : "post",
     "first" : "Una",
-    "third" : "Tria",
-    "fourth" : "Kvara",
-    "fifth" : "Kvina",
-    "last" : "Lasta",
     "By day of the month" : "Per tago de la monato",
     "On the" : "Je la",
+    "_day_::_days_" : ["tago","tagoj"],
+    "_week_::_weeks_" : ["semajno","semajnoj"],
     "_month_::_months_" : ["Monato","Monatoj"],
     "_year_::_years_" : ["Jaro","Jaroj"],
     "weekday" : "Semajntago",
     "weekend day" : "Semajnfintago",
+    "Resources" : "Rimedoj",
     "on {formattedDate}" : "je la {formattedDate}",
     "Global" : "Monda",
     "Subscribe" : "Aboni",
     "Time:" : "Tempo:",
     "Personal" : "Persona",
-    "[Today]" : "[Hodiaŭ]",
-    "[Tomorrow]" : "[Morgaŭ]",
-    "[Yesterday]" : "[Hieraŭ]",
-    "Details" : "Detaloj",
-    "Resources" : "Rimedoj",
-    "Close" : "Fermi",
+    "Edit event" : "Redakti okazaĵon",
+    "All day" : "Tuttage",
     "Untitled event" : "Sentitola okazaĵo",
+    "Close" : "Fermi",
     "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
+    "second" : "sekundo",
+    "third" : "Tria",
+    "fourth" : "Kvara",
+    "fifth" : "Kvina",
+    "last" : "Lasta",
     "Other" : "Alia",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
@@ -137,6 +140,7 @@ OC.L10N.register(
     "Canceled" : "Nuligita",
     "Categories" : "Kategorioj",
     "Add this as a new category" : "Aldoni tion kiel novan kategorion",
-    "User not found" : "Netrovita uzanto"
+    "User not found" : "Netrovita uzanto",
+    "Details" : "Detaloj"
 },
 "nplurals=2; plural=(n != 1);");
